use crate::ble::msg_service::{MessageService, MessageServiceEvent};
use crate::events;

use defmt::info;
use nrf_softdevice::ble::gatt_server;
use nrf_softdevice::ble::Connection;
use nrf_softdevice::ble::DisconnectedError;

#[nrf_softdevice::gatt_server]
pub struct Server {
    pub config: MessageService,
}

pub async fn run(conn: &Connection, server: &Server) -> DisconnectedError {
    info!("gatt started");

    let event_pub = events::EVENTS.publisher().unwrap();
    gatt_server::run(conn, server, |e| match e {
        ServerEvent::Config(e) => match e {
            MessageServiceEvent::MessageWrite(val) => {
                info!("new message: {}", val);
                event_pub.publish_immediate(events::Event::Message(val));
            }
        },
    })
    .await
}
